Finds the nearest m/z peak to a given value in a SpaMTP Object
Source:R/PlottingSpaMTP.R
FindNearestMZ.RdFinds the nearest m/z peak to a given value in a SpaMTP Object

R/PlottingSpaMTP.R
FindNearestMZ.RdFinds the nearest m/z peak to a given value in a SpaMTP Object